bayespy.nodes.SwitchingGaussianMarkovChain.has_plotter
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.has_plotter